@@ -63,10 +63,12 @@ QString ConfigStrings::OUTPUTDIR = QStringLiteral("outputdir");
 QString ConfigStrings::OUTPUTFORMATS = QStringLiteral("outputformats");
 QString ConfigStrings::OUTPUTPREFIXES = QStringLiteral("outputprefixes");
 QString ConfigStrings::OUTPUTSUFFIXES = QStringLiteral("outputsuffixes");
-QString ConfigStrings::PRODUCTNAME QStringLiteral("productname");
+QString ConfigStrings::PRODUCTNAME = QStringLiteral("productname");
 QString ConfigStrings::PROJECT = QStringLiteral("project");
 QString ConfigStrings::REDIRECTDOCUMENTATIONTODEVNULL =
         QStringLiteral("redirectdocumentationtodevnull");
+QString ConfigStrings::REPORTMISSINGALTTEXTFORIMAGES =
+        QStringLiteral("reportmissingalttextforimages");
 QString ConfigStrings::QHP = QStringLiteral("qhp");
 QString ConfigStrings::QUOTINGINFORMATION = QStringLiteral("quotinginformation");
 QString ConfigStrings::SCRIPTS = QStringLiteral("scripts");
@@ -425,6 +427,8 @@ void Config::load(const QString &fileName)
     // Prefetch values that are used internally
     m_exampleFiles = getCanonicalPathList(CONFIG_EXAMPLES);
     m_exampleDirs = getCanonicalPathList(CONFIG_EXAMPLEDIRS);
+    m_reportMissingAltTextForImages =
+            m_configVars.value(CONFIG_REPORTMISSINGALTTEXTFORIMAGES).asBool();
 }
 
 /*!
