@@ -10,6 +10,8 @@
 #include <QtCore/qstring.h>
 #include <QtCore/qlist.h>
 
+#include <optional>
+
 namespace Scanner {
 
 enum class InputFormat {
@@ -19,9 +21,13 @@ enum class InputFormat {
 Q_DECLARE_FLAGS(InputFormats, InputFormat)
 Q_DECLARE_OPERATORS_FOR_FLAGS(InputFormats)
 
-QList<Package> readFile(const QString &filePath, LogLevel logLevel);
-QList<Package> scanDirectory(const QString &directory, InputFormats inputFormats, LogLevel logLevel);
+enum class Check { Paths = 0x1, All = Paths };
+Q_DECLARE_FLAGS(Checks, Check)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Checks)
 
+std::optional<QList<Package>> readFile(const QString &filePath, Checks checks, LogLevel logLevel);
+std::optional<QList<Package>> scanDirectory(const QString &directory, InputFormats inputFormats,
+                                            Checks checks, LogLevel logLevel);
 }
 
 #endif // SCANNER_H
